==> maven-shade-plugin_3.1.1.orig.tar.xz: maven-shade-plugin-maven-shade-plugin-3.1.1/src/test/java/org/apache/maven/plugins/shade/resource/ApacheNoticeResourceTransformerTest.java <==
package org.apache.maven.plugins.shade.resource;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Locale;

import junit.framework.TestCase;

/**
 * Test for {@link ApacheNoticeResourceTransformer}.
 * 
 * @author Benjamin Bentmann
 * @version $Id$
 */
public class ApacheNoticeResourceTransformerTest
    extends TestCase
{

    private ApacheNoticeResourceTransformer transformer;

    static
    {
        /*
         * NOTE: The Turkish locale has an usual case transformation for the letters "I" and "i", making it a prime
         * choice to test for improper case-less string comparisions.
         */
        Locale.setDefault( new Locale( "tr" ) );
    }

    public void setUp()
    {
        this.transformer = new ApacheNoticeResourceTransformer();
    }

    public void testCanTransformResource()
    {
        assertTrue( this.transformer.canTransformResource( "META-INF/NOTICE" ) );
        assertTrue( this.transformer.canTransformResource( "META-INF/NOTICE.TXT" ) );
        assertTrue( this.transformer.canTransformResource( "META-INF/Notice.txt" ) );
        assertFalse( this.transformer.canTransformResource( "META-INF/MANIFEST.MF" ) );
    }

}

==> maven-shade-plugin_3.4.1.orig.tar.xz: maven-shade-plugin-maven-shade-plugin-3.4.1/src/test/java/org/apache/maven/plugins/shade/resource/ApacheNoticeResourceTransformerTest.java <==
package org.apache.maven.plugins.shade.resource;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Locale;

import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

/**
 * Test for {@link ApacheNoticeResourceTransformer}.
 * 
 * @author Benjamin Bentmann
 */
public class ApacheNoticeResourceTransformerTest
{

    private ApacheNoticeResourceTransformer transformer;

    static
    {
        /*
         * NOTE: The Turkish locale has an usual case transformation for the letters "I" and "i", making it a prime
         * choice to test for improper case-less string comparisions.
         */
        Locale.setDefault( new Locale( "tr" ) );
    }

    @Before
    public void setUp()
    {
        transformer = new ApacheNoticeResourceTransformer();
    }

    @Test
    public void testCanTransformResource()
    {
        assertTrue( transformer.canTransformResource( "META-INF/NOTICE" ) );
        assertTrue( transformer.canTransformResource( "META-INF/NOTICE.TXT" ) );
        assertTrue( transformer.canTransformResource( "META-INF/NOTICE.md" ) );
        assertTrue( transformer.canTransformResource( "META-INF/Notice.txt" ) );
        assertFalse( transformer.canTransformResource( "META-INF/MANIFEST.MF" ) );
    }

}
